# Document
## History
- 2022-12-01: v0.0.2
  - Add DatetimeField
  - add FieldValidator
- 2022-12-05: v0.0.3
  - Add redis set and list
- 2022-12-05: v0.0.4
  - Add is_init param to only update, when not read
- 2022-12-05: v0.0.5
  - Add hash actions
- 2022-12-05: v0.0.6
  - use utc in datetime
